@@ -248,17 +248,21 @@ class SupeRSS:
   def merge_extracted_data(self, feed_data, extracted_data):
     d = feed_data.copy()
 
-    # TODO: better merge heuristics
-    d['article_html'] = extracted_data['article_html']
-    d['text'] = extracted_data['text']
-
-    # add lists together
-    d['tags'] = list(set(feed_data['tags'] + extracted_data['tags']))
-    d['authors'] = list(set(feed_data['authors'] + extracted_data['authors']))
-    d['img_urls'] = list(set(feed_data['img_urls'] + extracted_data['img_urls']))
-    d['article_links'] = list(set(feed_data['article_links'] + extracted_data['article_links']))
-    d['article_imgs'] = list(set(feed_data['article_imgs'] + extracted_data['article_imgs']))
+    try:
+      # TODO: better merge heuristics
+      d['article_html'] = extracted_data['article_html']
+      d['text'] = extracted_data['text']
 
+      # add lists together
+      d['tags'] = list(set(feed_data['tags'] + extracted_data['tags']))
+      d['authors'] = list(set(feed_data['authors'] + extracted_data['authors']))
+      d['img_urls'] = list(set(feed_data['img_urls'] + extracted_data['img_urls']))
+      d['article_links'] = list(set(feed_data['article_links'] + extracted_data['article_links']))
+      d['article_imgs'] = list(set(feed_data['article_imgs'] + extracted_data['article_imgs']))
+    
+    except TypeError:
+      pass
+    
     return d 
   
   def extract_and_merge(self, entry):
